@@ -7,15 +7,15 @@ module("ajax");
 
 if ( !isLocal ) {
 
-test("$.ajax() - success callbacks", function() {
+test("jQuery.ajax() - success callbacks", function() {
 	expect( 8 );
 	
-	$.ajaxSetup({ timeout: 0 });
+	jQuery.ajaxSetup({ timeout: 0 });
 	
 	stop();
 	
 	setTimeout(function(){	
-        $('#foo').ajaxStart(function(){
+        jQuery('#foo').ajaxStart(function(){
             ok( true, "ajaxStart" );
         }).ajaxStop(function(){
             ok( true, "ajaxStop" );
@@ -30,7 +30,7 @@ test("$.ajax() - success callbacks", function() {
             ok( true, "ajaxSuccess" );
         });
         
-        $.ajax({
+        jQuery.ajax({
             url: url("data/name.html"),
             beforeSend: function(){ ok(true, "beforeSend"); },
             success: function(){ ok(true, "success"); },
@@ -40,11 +40,11 @@ test("$.ajax() - success callbacks", function() {
     }, 13);
 });
 
-test("$.ajax() - error callbacks", function() {
+test("jQuery.ajax() - error callbacks", function() {
     expect( 8 );
     stop();
     
-    $('#foo').ajaxStart(function(){
+    jQuery('#foo').ajaxStart(function(){
         ok( true, "ajaxStart" );
     }).ajaxStop(function(){
         ok( true, "ajaxStop" );
@@ -59,9 +59,9 @@ test("$.ajax() - error callbacks", function() {
         ok( false, "ajaxSuccess" );
     });
     
-    $.ajaxSetup({ timeout: 500 });
+    jQuery.ajaxSetup({ timeout: 500 });
     
-    $.ajax({
+    jQuery.ajax({
         url: url("data/name.php?wait=5"),
         beforeSend: function(){ ok(true, "beforeSend"); },
         success: function(){ ok(false, "success"); },
@@ -70,11 +70,11 @@ test("$.ajax() - error callbacks", function() {
     });
 });
 
-test("$.ajax() - disabled globals", function() {
+test("jQuery.ajax() - disabled globals", function() {
 	expect( 3 );
 	stop();
 	
-	$('#foo').ajaxStart(function(){
+	jQuery('#foo').ajaxStart(function(){
 		ok( false, "ajaxStart" );
 	}).ajaxStop(function(){
 		ok( false, "ajaxStop" );
@@ -88,7 +88,7 @@ test("$.ajax() - disabled globals", function() {
 		ok( false, "ajaxSuccess" );
 	});
 	
-	$.ajax({
+	jQuery.ajax({
 		global: false,
 		url: url("data/name.html"),
 		beforeSend: function(){ ok(true, "beforeSend"); },
@@ -101,30 +101,30 @@ test("$.ajax() - disabled globals", function() {
 	});
 });
 
-test("$.ajax - xml: non-namespace elements inside namespaced elements", function() {
+test("jQuery.ajax - xml: non-namespace elements inside namespaced elements", function() {
 	expect(3);
 	stop();
-	$.ajax({
+	jQuery.ajax({
 	  url: url("data/with_fries.xml"),
 	  dataType: "xml",
 	  success: function(resp) {
-	    equals( $("properties", resp).length, 1, 'properties in responseXML' );
-	    equals( $("jsconf", resp).length, 1, 'jsconf in responseXML' );
-	    equals( $("thing", resp).length, 2, 'things in responseXML' );
+	    equals( jQuery("properties", resp).length, 1, 'properties in responseXML' );
+	    equals( jQuery("jsconf", resp).length, 1, 'jsconf in responseXML' );
+	    equals( jQuery("thing", resp).length, 2, 'things in responseXML' );
 	    start();
 	  }
 	});
 });
 
-test("$.ajax - beforeSend", function() {
+test("jQuery.ajax - beforeSend", function() {
 	expect(1);
 	stop();
 	
 	var check = false;
 	
-	$.ajaxSetup({ timeout: 0 });
+	jQuery.ajaxSetup({ timeout: 0 });
 	
-	$.ajax({
+	jQuery.ajax({
 		url: url("data/name.html"), 
 		beforeSend: function(xml) {
 			check = true;
@@ -136,9 +136,9 @@ test("$.ajax - beforeSend", function() {
 	});
 });
 
-test("$.ajax - beforeSend, cancel request (#2688)", function() {
+test("jQuery.ajax - beforeSend, cancel request (#2688)", function() {
 	expect(2);
-	var request = $.ajax({
+	var request = jQuery.ajax({
 		url: url("data/name.html"), 
 		beforeSend: function() {
 			ok( true, "beforeSend got called, canceling" );
@@ -157,26 +157,25 @@ test("$.ajax - beforeSend, cancel request (#2688)", function() {
 	ok( request === false, "canceled request must return false instead of XMLHttpRequest instance" );
 });
 
-var foobar;
+window.foobar = null;
+window.testFoo = undefined;
 
-test("$.ajax - dataType html", function() {
+test("jQuery.ajax - dataType html", function() {
 	expect(5);
 	stop();
 	
-	foobar = null;
-	testFoo = undefined;
-
 	var verifyEvaluation = function() {
-	  equals( testFoo, "foo", 'Check if script was evaluated for datatype html' );
-	  equals( foobar, "bar", 'Check if script src was evaluated for datatype html' );
-	  start();
+		equals( testFoo, "foo", 'Check if script was evaluated for datatype html' );
+		equals( foobar, "bar", 'Check if script src was evaluated for datatype html' );
+	  
+		start();
 	};
 
-	$.ajax({
+	jQuery.ajax({
 	  dataType: "html",
 	  url: url("data/test.html"),
 	  success: function(data) {
-	  	$("#ap").html(data);
+	  	jQuery("#ap").html(data);
 	    ok( data.match(/^html text/), 'Check content for datatype html' );
 	    setTimeout(verifyEvaluation, 600);
 	  }
@@ -186,85 +185,86 @@ test("$.ajax - dataType html", function() {
 test("serialize()", function() {
 	expect(6);
 	
-	equals( $('#form').serialize(),
-		"action=Test&radio2=on&check=on&hidden=&foo%5Bbar%5D=&name=name&select1=&select2=3&select3=1&select3=2",
+	equals( jQuery('#form').serialize(),
+		"action=Test&radio2=on&check=on&hidden=&foo%5Bbar%5D=&name=name&search=search&select1=&select2=3&select3=1&select3=2",
 		'Check form serialization as query string');
 		
-	equals( $('#form :input').serialize(),
-		"action=Test&radio2=on&check=on&hidden=&foo%5Bbar%5D=&name=name&select1=&select2=3&select3=1&select3=2",
+	equals( jQuery('#form :input').serialize(),
+		"action=Test&radio2=on&check=on&hidden=&foo%5Bbar%5D=&name=name&search=search&select1=&select2=3&select3=1&select3=2",
 		'Check input serialization as query string');
 	
-	equals( $('#testForm').serialize(), 
+	equals( jQuery('#testForm').serialize(), 
 		'T3=%3F%0AZ&H1=x&H2=&PWD=&T1=&T2=YES&My+Name=me&S1=abc&S3=YES&S4=', 
 		'Check form serialization as query string');
 		
-	equals( $('#testForm :input').serialize(), 
+	equals( jQuery('#testForm :input').serialize(), 
 		'T3=%3F%0AZ&H1=x&H2=&PWD=&T1=&T2=YES&My+Name=me&S1=abc&S3=YES&S4=', 
 		'Check input serialization as query string');
 		
-	equals( $('#form, #testForm').serialize(),
-		"action=Test&radio2=on&check=on&hidden=&foo%5Bbar%5D=&name=name&select1=&select2=3&select3=1&select3=2&T3=%3F%0AZ&H1=x&H2=&PWD=&T1=&T2=YES&My+Name=me&S1=abc&S3=YES&S4=",
+	equals( jQuery('#form, #testForm').serialize(),
+		"action=Test&radio2=on&check=on&hidden=&foo%5Bbar%5D=&name=name&search=search&select1=&select2=3&select3=1&select3=2&T3=%3F%0AZ&H1=x&H2=&PWD=&T1=&T2=YES&My+Name=me&S1=abc&S3=YES&S4=",
 		'Multiple form serialization as query string');
 		
-	equals( $('#form, #testForm :input').serialize(),
-		"action=Test&radio2=on&check=on&hidden=&foo%5Bbar%5D=&name=name&select1=&select2=3&select3=1&select3=2&T3=%3F%0AZ&H1=x&H2=&PWD=&T1=&T2=YES&My+Name=me&S1=abc&S3=YES&S4=",
+	equals( jQuery('#form, #testForm :input').serialize(),
+		"action=Test&radio2=on&check=on&hidden=&foo%5Bbar%5D=&name=name&search=search&select1=&select2=3&select3=1&select3=2&T3=%3F%0AZ&H1=x&H2=&PWD=&T1=&T2=YES&My+Name=me&S1=abc&S3=YES&S4=",
 		'Mixed form/input serialization as query string');
 });
 
-test("$.param()", function() {
+test("jQuery.param()", function() {
 	expect(4);
 	var params = {foo:"bar", baz:42, quux:"All your base are belong to us"};
-	equals( $.param(params), "foo=bar&baz=42&quux=All+your+base+are+belong+to+us", "simple" );
+	equals( jQuery.param(params), "foo=bar&baz=42&quux=All+your+base+are+belong+to+us", "simple" );
 	
 	params = {someName: [1, 2, 3], regularThing: "blah" };
-	equals( $.param(params), "someName=1&someName=2&someName=3&regularThing=blah", "with array" );
+	equals( jQuery.param(params), "someName=1&someName=2&someName=3&regularThing=blah", "with array" );
 	
 	params = {"foo[]":["baz", 42, "All your base are belong to us"]};
-	equals( $.param(params), "foo%5B%5D=baz&foo%5B%5D=42&foo%5B%5D=All+your+base+are+belong+to+us", "more array" );
+	equals( jQuery.param(params), "foo%5B%5D=baz&foo%5B%5D=42&foo%5B%5D=All+your+base+are+belong+to+us", "more array" );
 	
 	params = {"foo[bar]":"baz", "foo[beep]":42, "foo[quux]":"All your base are belong to us"};
-	equals( $.param(params), "foo%5Bbar%5D=baz&foo%5Bbeep%5D=42&foo%5Bquux%5D=All+your+base+are+belong+to+us", "even more arrays" );
+	equals( jQuery.param(params), "foo%5Bbar%5D=baz&foo%5Bbeep%5D=42&foo%5Bquux%5D=All+your+base+are+belong+to+us", "even more arrays" );
 });
 
 test("synchronous request", function() {
 	expect(1);
-	ok( /^{ "data"/.test( $.ajax({url: url("data/json_obj.js"), async: false}).responseText ), "check returned text" );
+	ok( /^{ "data"/.test( jQuery.ajax({url: url("data/json_obj.js"), async: false}).responseText ), "check returned text" );
 });
 
 test("synchronous request with callbacks", function() {
 	expect(2);
 	var result;
-	$.ajax({url: url("data/json_obj.js"), async: false, success: function(data) { ok(true, "sucess callback executed"); result = data; } });
+	jQuery.ajax({url: url("data/json_obj.js"), async: false, success: function(data) { ok(true, "sucess callback executed"); result = data; } });
 	ok( /^{ "data"/.test( result ), "check returned text" );
 });
 
 test("pass-through request object", function() {
 	expect(8);
-	stop(true);
+	stop();
 	
 	var target = "data/name.html";
 	var successCount = 0;
 	var errorCount = 0;
-  var errorEx = "";
+	var errorEx = "";
 	var success = function() {
 		successCount++;
 	};
-	$("#foo").ajaxError(function (e, xml, s, ex) {
+	jQuery("#foo").ajaxError(function (e, xml, s, ex) {
 		errorCount++;
-    errorEx += ": " + xml.status;
+		errorEx += ": " + xml.status;
 	});
-	$("#foo").one('ajaxStop', function () {
+	jQuery("#foo").one('ajaxStop', function () {
 		equals(successCount, 5, "Check all ajax calls successful");
 		equals(errorCount, 0, "Check no ajax errors (status" + errorEx + ")");
-		$("#foo").unbind('ajaxError');
+		jQuery("#foo").unbind('ajaxError');
+		
 		start();
 	});
 	
-	ok( $.get(url(target), success), "get" );
-	ok( $.post(url(target), success), "post" );
-	ok( $.getScript(url("data/test.js"), success), "script" );
-	ok( $.getJSON(url("data/json_obj.js"), success), "json" );
-	ok( $.ajax({url: url(target), success: success}), "generic" );
+	ok( jQuery.get(url(target), success), "get" );
+	ok( jQuery.post(url(target), success), "post" );
+	ok( jQuery.getScript(url("data/test.js"), success), "script" );
+	ok( jQuery.getJSON(url("data/json_obj.js"), success), "json" );
+	ok( jQuery.ajax({url: url(target), success: success}), "generic" );
 });
 
 test("ajax cache", function () {
@@ -273,7 +273,7 @@ test("ajax cache", function () {
 	
 	var count = 0;
 
-	$("#firstp").bind("ajaxSuccess", function (e, xml, s) {
+	jQuery("#firstp").bind("ajaxSuccess", function (e, xml, s) {
 		var re = /_=(.*?)(&|$)/g;
     var oldOne = null;
 		for (var i = 0; i < 6; i++) {
@@ -289,12 +289,12 @@ test("ajax cache", function () {
 			start();
 	});
 
-	ok( $.ajax({url: "data/text.php", cache:false}), "test with no parameters" );
-	ok( $.ajax({url: "data/text.php?pizza=true", cache:false}), "test with 1 parameter" );
-	ok( $.ajax({url: "data/text.php?_=tobereplaced555", cache:false}), "test with _= parameter" );
-	ok( $.ajax({url: "data/text.php?pizza=true&_=tobereplaced555", cache:false}), "test with 1 parameter plus _= one" );
-	ok( $.ajax({url: "data/text.php?_=tobereplaced555&tv=false", cache:false}), "test with 1 parameter plus _= one before it" );
-	ok( $.ajax({url: "data/text.php?name=David&_=tobereplaced555&washere=true", cache:false}), "test with 2 parameters surrounding _= one" );
+	ok( jQuery.ajax({url: "data/text.php", cache:false}), "test with no parameters" );
+	ok( jQuery.ajax({url: "data/text.php?pizza=true", cache:false}), "test with 1 parameter" );
+	ok( jQuery.ajax({url: "data/text.php?_=tobereplaced555", cache:false}), "test with _= parameter" );
+	ok( jQuery.ajax({url: "data/text.php?pizza=true&_=tobereplaced555", cache:false}), "test with 1 parameter plus _= one" );
+	ok( jQuery.ajax({url: "data/text.php?_=tobereplaced555&tv=false", cache:false}), "test with 1 parameter plus _= one before it" );
+	ok( jQuery.ajax({url: "data/text.php?name=David&_=tobereplaced555&washere=true", cache:false}), "test with 2 parameters surrounding _= one" );
 });
 
 test("global ajaxSettings", function() {
@@ -304,16 +304,16 @@ test("global ajaxSettings", function() {
     var orig = { url: "data/with_fries.xml" };
 	var t;
 
-	$.ajaxSetup({ data: {foo: 'bar', bar: 'BAR'} });
+	jQuery.ajaxSetup({ data: {foo: 'bar', bar: 'BAR'} });
 
     t = jQuery.extend({}, orig);
 	t.data = {};
-    $.ajax(t);
+    jQuery.ajax(t);
 	ok( t.url.indexOf('foo') > -1 && t.url.indexOf('bar') > -1, "Check extending {}" );
 
     t = jQuery.extend({}, orig);
 	t.data = { zoo: 'a', ping: 'b' };
-    $.ajax(t);
+    jQuery.ajax(t);
 	ok( t.url.indexOf('ping') > -1 && t.url.indexOf('zoo') > -1 && t.url.indexOf('foo') > -1 && t.url.indexOf('bar') > -1, "Check extending { zoo: 'a', ping: 'b' }" );
 	
 	jQuery.ajaxSettings = tmp;
@@ -321,15 +321,15 @@ test("global ajaxSettings", function() {
 
 test("load(String)", function() {
 	expect(1);
-	stop(true); // check if load can be called with only url
-	$('#first').load("data/name.html", start);
+	stop(); // check if load can be called with only url
+	jQuery('#first').load("data/name.html", start);
 });
 
 test("load('url selector')", function() {
 	expect(1);
-	stop(true); // check if load can be called with only url
-	$('#first').load("data/test3.html div.user", function(){
-		equals( $(this).children("div").length, 2, "Verify that specific elements were injected" );
+	stop(); // check if load can be called with only url
+	jQuery('#first').load("data/test3.html div.user", function(){
+		equals( jQuery(this).children("div").length, 2, "Verify that specific elements were injected" );
 		start();
 	});
 });
@@ -337,21 +337,21 @@ test("load('url selector')", function() {
 test("load(String, Function) with ajaxSetup on dataType json, see #2046", function() {
 	expect(1);
 	stop();
-	$.ajaxSetup({ dataType: "json" });
-	$("#first").ajaxComplete(function (e, xml, s) {
+	jQuery.ajaxSetup({ dataType: "json" });
+	jQuery("#first").ajaxComplete(function (e, xml, s) {
 		equals( s.dataType, "html", "Verify the load() dataType was html" );
-		$("#first").unbind("ajaxComplete");
-		$.ajaxSetup({ dataType: "" });
+		jQuery("#first").unbind("ajaxComplete");
+		jQuery.ajaxSetup({ dataType: "" });
 		start();
 	});
-	$('#first').load("data/test3.html");
+	jQuery('#first').load("data/test3.html");
 });
 
 test("load(String, Function) - simple: inject text into DOM", function() {
 	expect(2);
 	stop();
-	$('#first').load(url("data/name.html"), function() {
-		ok( /^ERROR/.test($('#first').text()), 'Check if content was injected into the DOM' );
+	jQuery('#first').load(url("data/name.html"), function() {
+		ok( /^ERROR/.test(jQuery('#first').text()), 'Check if content was injected into the DOM' );
 		start();
 	});
 });
@@ -359,16 +359,16 @@ test("load(String, Function) - simple: inject text into DOM", function() {
 test("load(String, Function) - check scripts", function() {
 	expect(7);
 	stop();
-	window.testFoo = undefined;
-	window.foobar = null;
+	
 	var verifyEvaluation = function() {
 		equals( foobar, "bar", 'Check if script src was evaluated after load' );
-		equals( $('#ap').html(), 'bar', 'Check if script evaluation has modified DOM');
-		 start();
+		equals( jQuery('#ap').html(), 'bar', 'Check if script evaluation has modified DOM');
+		
+		start();
 	};
-	$('#first').load(url('data/test.html'), function() {
-		ok( $('#first').html().match(/^html text/), 'Check content after loading html' );
-		equals( $('#foo').html(), 'foo', 'Check if script evaluation has modified DOM');
+	jQuery('#first').load(url('data/test.html'), function() {
+		ok( jQuery('#first').html().match(/^html text/), 'Check content after loading html' );
+		equals( jQuery('#foo').html(), 'foo', 'Check if script evaluation has modified DOM');
 		equals( testFoo, "foo", 'Check if script was evaluated after load' );
 		setTimeout(verifyEvaluation, 600);
 	});
@@ -377,21 +377,46 @@ test("load(String, Function) - check scripts", function() {
 test("load(String, Function) - check file with only a script tag", function() {
 	expect(3);
 	stop();
-	testFoo = undefined;
-	$('#first').load(url('data/test2.html'), function() {
-		equals( $('#foo').html(), 'foo', 'Check if script evaluation has modified DOM');
+
+	jQuery('#first').load(url('data/test2.html'), function() {
+		equals( jQuery('#foo').html(), 'foo', 'Check if script evaluation has modified DOM');
 		equals( testFoo, "foo", 'Check if script was evaluated after load' );
+		
 		start();
 	});
 });
 
-test("$.get(String, Hash, Function) - parse xml and use text() on nodes", function() {
+test("load(String, Object, Function)", function() {
 	expect(2);
 	stop();
-	$.get(url('data/dashboard.xml'), function(xml) {
+	
+	jQuery('<div />').load(url('data/params_html.php'), { foo:3, bar:'ok' }, function() {
+		var $post = jQuery(this).find('#post');		
+		equals( $post.find('#foo').text(), '3', 'Check if a hash of data is passed correctly');
+		equals( $post.find('#bar').text(), 'ok', 'Check if a hash of data is passed correctly');
+		start();
+	});
+});
+
+test("load(String, String, Function)", function() {
+	expect(2);
+	stop();
+	
+	jQuery('<div />').load(url('data/params_html.php'), 'foo=3&bar=ok', function() {
+		var $get = jQuery(this).find('#get');		
+		equals( $get.find('#foo').text(), '3', 'Check if a string of data is passed correctly');
+		equals( $get.find('#bar').text(), 'ok', 'Check if a  of data is passed correctly');
+		start();
+	});
+});
+
+test("jQuery.get(String, Hash, Function) - parse xml and use text() on nodes", function() {
+	expect(2);
+	stop();
+	jQuery.get(url('data/dashboard.xml'), function(xml) {
 		var content = [];
-		$('tab', xml).each(function() {
-			content.push($(this).text());
+		jQuery('tab', xml).each(function() {
+			content.push(jQuery(this).text());
 		});
 		equals( content[0], 'blabla', 'Check first tab');
 		equals( content[1], 'blublu', 'Check second tab');
@@ -399,23 +424,24 @@ test("$.get(String, Hash, Function) - parse xml and use text() on nodes", functi
 	});
 });
 
-test("$.getScript(String, Function) - with callback", function() {
+test("jQuery.getScript(String, Function) - with callback", function() {
 	expect(2);
 	stop();
-	window.foobar = null;
-	$.getScript(url("data/test.js"), function() {
+	jQuery.getScript(url("data/test.js"), function() {
 		equals( foobar, "bar", 'Check if script was evaluated' );
 		setTimeout(start, 100);
 	});
 });
 
-test("$.getScript(String, Function) - no callback", function() {
+test("jQuery.getScript(String, Function) - no callback", function() {
 	expect(1);
-	stop(true);
-	$.getScript(url("data/test.js"), start);
+	stop();
+	jQuery.getScript(url("data/test.js"), function(){
+		start();
+	});
 });
 
-test("$.ajax() - JSONP, Local", function() {
+test("jQuery.ajax() - JSONP, Local", function() {
 	expect(7);
 
 	var count = 0;
@@ -423,7 +449,7 @@ test("$.ajax() - JSONP, Local", function() {
 
 	stop();
 
-	$.ajax({
+	jQuery.ajax({
 		url: "data/jsonp.php",
 		dataType: "jsonp",
 		success: function(data){
@@ -436,7 +462,7 @@ test("$.ajax() - JSONP, Local", function() {
 		}
 	});
 
-	$.ajax({
+	jQuery.ajax({
 		url: "data/jsonp.php?callback=?",
 		dataType: "jsonp",
 		success: function(data){
@@ -449,7 +475,7 @@ test("$.ajax() - JSONP, Local", function() {
 		}
 	});
 
-	$.ajax({
+	jQuery.ajax({
 		url: "data/jsonp.php",
 		dataType: "jsonp",
 		data: "callback=?",
@@ -463,7 +489,7 @@ test("$.ajax() - JSONP, Local", function() {
 		}
 	});
 
-	$.ajax({
+	jQuery.ajax({
 		url: "data/jsonp.php",
 		dataType: "jsonp",
 		jsonp: "callback",
@@ -477,7 +503,7 @@ test("$.ajax() - JSONP, Local", function() {
 		}
 	});
 
-	$.ajax({
+	jQuery.ajax({
 		type: "POST",
 		url: "data/jsonp.php",
 		dataType: "jsonp",
@@ -491,7 +517,7 @@ test("$.ajax() - JSONP, Local", function() {
 		}
 	});
 
-	$.ajax({
+	jQuery.ajax({
 		type: "POST",
 		url: "data/jsonp.php",
 		data: "callback=?",
@@ -506,7 +532,7 @@ test("$.ajax() - JSONP, Local", function() {
 		}
 	});
 
-	$.ajax({
+	jQuery.ajax({
 		type: "POST",
 		url: "data/jsonp.php",
 		jsonp: "callback",
@@ -522,7 +548,7 @@ test("$.ajax() - JSONP, Local", function() {
 	});
 });
 
-test("$.ajax() - JSONP, Remote", function() {
+test("jQuery.ajax() - JSONP, Remote", function() {
 	expect(4);
 
 	var count = 0;
@@ -532,7 +558,7 @@ test("$.ajax() - JSONP, Remote", function() {
 
 	stop();
 
-	$.ajax({
+	jQuery.ajax({
 		url: base + "data/jsonp.php",
 		dataType: "jsonp",
 		success: function(data){
@@ -545,7 +571,7 @@ test("$.ajax() - JSONP, Remote", function() {
 		}
 	});
 
-	$.ajax({
+	jQuery.ajax({
 		url: base + "data/jsonp.php?callback=?",
 		dataType: "jsonp",
 		success: function(data){
@@ -558,7 +584,7 @@ test("$.ajax() - JSONP, Remote", function() {
 		}
 	});
 
-	$.ajax({
+	jQuery.ajax({
 		url: base + "data/jsonp.php",
 		dataType: "jsonp",
 		data: "callback=?",
@@ -572,7 +598,7 @@ test("$.ajax() - JSONP, Remote", function() {
 		}
 	});
 
-	$.ajax({
+	jQuery.ajax({
 		url: base + "data/jsonp.php",
 		dataType: "jsonp",
 		jsonp: "callback",
@@ -587,15 +613,14 @@ test("$.ajax() - JSONP, Remote", function() {
 	});
 });
 
-test("$.ajax() - script, Remote", function() {
+test("jQuery.ajax() - script, Remote", function() {
 	expect(2);
 
 	var base = window.location.href.replace(/\?.*$/, "");
 
 	stop();
 
-	window.foobar = null;
-	$.ajax({
+	jQuery.ajax({
 		url: base + "data/test.js",
 		dataType: "script",
 		success: function(data){
@@ -605,15 +630,14 @@ test("$.ajax() - script, Remote", function() {
 	});
 });
 
-test("$.ajax() - script, Remote with POST", function() {
+test("jQuery.ajax() - script, Remote with POST", function() {
 	expect(3);
 
 	var base = window.location.href.replace(/\?.*$/, "");
 
 	stop();
 
-	window.foobar = null;
-	$.ajax({
+	jQuery.ajax({
 		url: base + "data/test.js",
 		type: "POST",
 		dataType: "script",
@@ -625,7 +649,7 @@ test("$.ajax() - script, Remote with POST", function() {
 	});
 });
 
-test("$.ajax() - script, Remote with scheme-less URL", function() {
+test("jQuery.ajax() - script, Remote with scheme-less URL", function() {
 	expect(2);
 
 	var base = window.location.href.replace(/\?.*$/, "");
@@ -633,8 +657,7 @@ test("$.ajax() - script, Remote with scheme-less URL", function() {
 
 	stop();
 
-	window.foobar = null;
-	$.ajax({
+	jQuery.ajax({
 		url: base + "data/test.js",
 		dataType: "script",
 		success: function(data){
@@ -644,10 +667,10 @@ test("$.ajax() - script, Remote with scheme-less URL", function() {
 	});
 });
 
-test("$.getJSON(String, Hash, Function) - JSON array", function() {
+test("jQuery.getJSON(String, Hash, Function) - JSON array", function() {
 	expect(4);
 	stop();
-	$.getJSON(url("data/json.php"), {json: "array"}, function(json) {
+	jQuery.getJSON(url("data/json.php"), {json: "array"}, function(json) {
 	  equals( json[0].name, 'John', 'Check JSON: first, name' );
 	  equals( json[0].age, 21, 'Check JSON: first, age' );
 	  equals( json[1].name, 'Peter', 'Check JSON: second, name' );
@@ -656,60 +679,63 @@ test("$.getJSON(String, Hash, Function) - JSON array", function() {
 	});
 });
 
-test("$.getJSON(String, Function) - JSON object", function() {
+test("jQuery.getJSON(String, Function) - JSON object", function() {
 	expect(2);
 	stop();
-	$.getJSON(url("data/json.php"), function(json) {
+	jQuery.getJSON(url("data/json.php"), function(json) {
 	  equals( json.data.lang, 'en', 'Check JSON: lang' );
 	  equals( json.data.length, 25, 'Check JSON: length' );
 	  start();
 	});
 });
 
-test("$.getJSON(String, Function) - JSON object with absolute url to local content", function() {
+test("jQuery.getJSON(String, Function) - JSON object with absolute url to local content", function() {
 	expect(2);
 
 	var base = window.location.href.replace(/\?.*$/, "");
 
 	stop();
-	$.getJSON(url(base + "data/json.php"), function(json) {
+	jQuery.getJSON(url(base + "data/json.php"), function(json) {
 	  equals( json.data.lang, 'en', 'Check JSON: lang' );
 	  equals( json.data.length, 25, 'Check JSON: length' );
 	  start();
 	});
 });
 
-test("$.post(String, Hash, Function) - simple with xml", function() {
+test("jQuery.post(String, Hash, Function) - simple with xml", function() {
 	expect(4);
 	stop();
-	$.post(url("data/name.php"), {xml: "5-2"}, function(xml){
-	  $('math', xml).each(function() {
-		    equals( $('calculation', this).text(), '5-2', 'Check for XML' );
-		    equals( $('result', this).text(), '3', 'Check for XML' );
+	var done = 0;
+
+	jQuery.post(url("data/name.php"), {xml: "5-2"}, function(xml){
+	  jQuery('math', xml).each(function() {
+		    equals( jQuery('calculation', this).text(), '5-2', 'Check for XML' );
+		    equals( jQuery('result', this).text(), '3', 'Check for XML' );
 		 });
+	  if ( ++done === 2 ) start();
 	});
 
-	$.post(url("data/name.php?xml=5-2"), {}, function(xml){
-	  $('math', xml).each(function() {
-		    equals( $('calculation', this).text(), '5-2', 'Check for XML' );
-		    equals( $('result', this).text(), '3', 'Check for XML' );
+	jQuery.post(url("data/name.php?xml=5-2"), {}, function(xml){
+	  jQuery('math', xml).each(function() {
+		    equals( jQuery('calculation', this).text(), '5-2', 'Check for XML' );
+		    equals( jQuery('result', this).text(), '3', 'Check for XML' );
 		 });
-	  start();
+	  if ( ++done === 2 ) start();
 	});
 });
 
-test("$.ajaxSetup({timeout: Number}) - with global timeout", function() {
+test("jQuery.ajaxSetup({timeout: Number}) - with global timeout", function() {
 	stop();
 	
 	var passed = 0;
 
-	$.ajaxSetup({timeout: 1000});
+	jQuery.ajaxSetup({timeout: 1000});
 	
 	var pass = function() {
 		passed++;
 		if ( passed == 2 ) {
 			ok( true, 'Check local and global callbacks after timeout' );
-	     	$('#main').unbind("ajaxError");
+	     	jQuery('#main').unbind("ajaxError");
 			start();
 		}
 	};
@@ -719,9 +745,9 @@ test("$.ajaxSetup({timeout: Number}) - with global timeout", function() {
 		start();
 	};
 	
-	$('#main').ajaxError(pass);
+	jQuery('#main').ajaxError(pass);
 	
-	$.ajax({
+	jQuery.ajax({
 	  type: "GET",
 	  url: url("data/name.php?wait=5"),
 	  error: pass,
@@ -729,14 +755,14 @@ test("$.ajaxSetup({timeout: Number}) - with global timeout", function() {
 	});
 	
 	// reset timeout
-	$.ajaxSetup({timeout: 0});
+	jQuery.ajaxSetup({timeout: 0});
 });
 
-test("$.ajaxSetup({timeout: Number}) with localtimeout", function() {
+test("jQuery.ajaxSetup({timeout: Number}) with localtimeout", function() {
 	stop();
-	$.ajaxSetup({timeout: 50});
+	jQuery.ajaxSetup({timeout: 50});
 
-	$.ajax({
+	jQuery.ajax({
 	  type: "GET",
 	  timeout: 5000,
 	  url: url("data/name.php?wait=1"),
@@ -751,13 +777,13 @@ test("$.ajaxSetup({timeout: Number}) with localtimeout", function() {
 	});
 
 	// reset timeout
-	$.ajaxSetup({timeout: 0});
+	jQuery.ajaxSetup({timeout: 0});
 });
 
-test("$.ajax - simple get", function() {
+test("jQuery.ajax - simple get", function() {
 	expect(1);
 	stop();
-	$.ajax({
+	jQuery.ajax({
 	  type: "GET",
 	  url: url("data/name.php?name=foo"),
 	  success: function(msg){
@@ -767,10 +793,10 @@ test("$.ajax - simple get", function() {
 	});
 });
 
-test("$.ajax - simple post", function() {
+test("jQuery.ajax - simple post", function() {
 	expect(1);
 	stop();
-	$.ajax({
+	jQuery.ajax({
 	  type: "POST",
 	  url: url("data/name.php"),
 	  data: "name=peter",
@@ -784,20 +810,21 @@ test("$.ajax - simple post", function() {
 test("ajaxSetup()", function() {
 	expect(1);
 	stop();
-	$.ajaxSetup({
+	jQuery.ajaxSetup({
 		url: url("data/name.php?name=foo"),
 		success: function(msg){
 	    	equals( msg, 'bar', 'Check for GET' );
 			start();
 		}
 	});
-	$.ajax();
+	jQuery.ajax();
 });
 
+/*
 test("custom timeout does not set error message when timeout occurs, see #970", function() {
 	stop();
-	$.ajax({
-		url: "data/name.php?wait=10",
+	jQuery.ajax({
+		url: "data/name.php?wait=1",
 		timeout: 500,
 		error: function(request, status) {
 			ok( status != null, "status shouldn't be null in error handler" );
@@ -806,10 +833,11 @@ test("custom timeout does not set error message when timeout occurs, see #970",
 		}
 	});
 });
+*/
 
 test("data option: evaluate function values (#2806)", function() {
 	stop();
-	$.ajax({
+	jQuery.ajax({
 		url: "data/echoQuery.php",
 		data: {
 			key: function() {
